=======
Credits
=======

Development Lead
----------------

* Marek Wywiał <onjinx@gmail.com>

Contributors
------------

* Marcin Nowak <marcin.j.nowak@gmail.com>
* Bartek Radwan <bartek@sq9mev.info>
